Harmonizome.download_gene_functional_annotations()

Download and get all functional annotations for a gene across specified datasets.

Usage

Harmonizome.download_gene_functional_annotations(
    gene_symbol,
    datasets=None,
)

This method downloads the necessary data files and extracts associations for the specified gene from the gene-attribute matrices.

Parameters

gene_symbol: str

Gene symbol (e.g., ‘BRCA1’, ‘STAT3’)

datasets: Optional[list[str]] = None
List of dataset names to search. If None, searches all datasets.

Returns

dict[str, Any]
Dictionary with dataset names as keys and annotation data as values.