Harmonizome.get_gene_functional_annotations()

Get functional annotations for a gene using the Harmonizome API.

Usage

Harmonizome.get_gene_functional_annotations(
    gene_symbol,
    datasets=None,
)

This method uses the API directly without downloading any files. It leverages the showAssociations=true parameter to get functional associations for a gene.

Parameters

gene_symbol: str

Gene symbol (e.g., ‘BRCA1’, ‘STAT3’)

datasets: Optional[list[str]] = None
List of dataset names to search. If None, searches all datasets.

Returns

dict[str, Any]

Dictionary formatted like Harmonizome web interface with:

  • gene_info: Basic gene information

  • functional_associations: List of datasets with associations