Harmonizome.get()
Returns a single entity or a list, depending on if a name is
Usage
Harmonizome.get(
entity,
name=None,
start_at=None,
)provided. If no name is provided and start_at is specified, returns a list starting at that cursor position.